CAPPr Docs
================================

|gittycat| `GitHub <https://github.com/kddubey/cappr>`_

.. |gittycat| image:: _static/github-mark.png
              :scale: 10%

Perform zero-shot text classification by estimating the probability that an inputted
completion comes after an inputted prompt. Hence the name:

   | **C**\ompletion
   | **A**\fter
   | **P**\rompt
   | **Pr**\obability

The method is fleshed out in my `question on Cross Validated`_.

.. _question on Cross Validated: https://stats.stackexchange.com/q/601159/337906

.. note:: This package is in early stages, and the method needs to be evaluated on more
          datasets.


Get started
===========

.. toctree::
   :maxdepth: 2

   walkthrough


Package
=======

.. toctree::
   :maxdepth: 2

   cappr


Details
=======

.. toctree::
   :maxdepth: 2

   research


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
